@@ -24,9 +24,6 @@ if [ "$USE_CONDA" = "true" ]; then
         conda install pyzmq=19
     fi
 
-    # Install decorator 4.4.2 until spyder-kernels 2.0.1 is released in Anaconda
-    conda install -q -y decorator=4.4.2
-
     # Remove packages we have subrepos for
     conda remove spyder-kernels --force -q -y
     conda remove python-language-server --force -q -y
