@@ -18,6 +18,7 @@ import sys
 from spyder.config.base import CHECK_ALL, EXCLUDED_NAMES
 from spyder.config.fonts import MEDIUM, SANS_SERIF
 from spyder.config.utils import IMPORT_EXT
+from spyder.config.snippets import SNIPPETS
 from spyder.config.appearance import APPEARANCE
 from spyder.plugins.editor.utils.findtasks import TASKS_PATTERN
 from spyder.utils.introspection.module_completion import PREFERRED_MODULES
@@ -30,14 +31,14 @@ from spyder.utils.introspection.module_completion import PREFERRED_MODULES
 EXCLUDE_PATTERNS = ['*.csv, *.dat, *.log, *.tmp, *.bak, *.orig']
 
 # Extensions that should be visible in Spyder's file/project explorers
-SHOW_EXT = ['.py', '.ipynb', '.txt', '.dat', '.pdf', '.png', '.svg']
+SHOW_EXT = ['.py', '.ipynb', '.dat', '.pdf', '.png', '.svg']
 
 # Extensions supported by Spyder (Editor or Variable explorer)
 USEFUL_EXT = IMPORT_EXT + SHOW_EXT
 
 # Name filters for file/project explorers (excluding files without extension)
-NAME_FILTERS = ['README', 'INSTALL', 'LICENSE', 'CHANGELOG'] + \
-               ['*' + _ext for _ext in USEFUL_EXT if _ext]
+NAME_FILTERS = ['README', 'INSTALL', 'LICENSE', 'CHANGELOG']
+NAME_FILTERS += ['*' + _ext for _ext in USEFUL_EXT if _ext not in NAME_FILTERS]
 
 # Port used to detect if there is a running instance and to communicate with
 # it to open external files
@@ -62,15 +63,12 @@ DEFAULTS = [
               'opengl': 'software',
               'single_instance': True,
               'open_files_port': OPEN_FILES_PORT,
-              'tear_off_menus': False,
               'mac_open_file': False,
               'normal_screen_resolution': True,
               'high_dpi_scaling': False,
               'high_dpi_custom_scale_factor': False,
               'high_dpi_custom_scale_factors': '1.5',
-              'vertical_dockwidget_titlebars': False,
               'vertical_tabs': False,
-              'animated_docks': True,
               'prompt_on_exit': False,
               'panes_locked': True,
               'window/size': (1260, 740),
@@ -78,6 +76,24 @@ DEFAULTS = [
               'window/is_maximized': True,
               'window/is_fullscreen': False,
               'window/prefs_dialog_size': (1050, 530),
+              'use_custom_margin': True,
+              'custom_margin': 0,
+              'use_custom_cursor_blinking': False,
+              'show_internal_errors': True,
+              'check_updates_on_startup': True,
+              'cursor/width': 2,
+              'completion/size': (300, 180),
+              'report_error/remember_token': False,
+              'show_tour_message': True,
+              }),
+            ('toolbar',
+             {
+              'enable': True,
+              'toolbars_visible': True,
+              'last_visible_toolbars': [],
+             }),
+            ('statusbar',
+             {
               'show_status_bar': True,
               'memory_usage/enable': True,
               'memory_usage/timeout': 2000,
@@ -85,22 +101,14 @@ DEFAULTS = [
               'cpu_usage/timeout': 2000,
               'clock/enable': False,
               'clock/timeout': 1000,
-              'use_custom_margin': True,
-              'custom_margin': 0,
-              'use_custom_cursor_blinking': False,
-              'show_internal_errors': True,
-              'check_updates_on_startup': True,
-              'toolbars_visible': True,
-              'cursor/width': 2,
-              'completion/size': (300, 180),
-              'report_error/remember_token': False,
               }),
             ('quick_layouts',
              {
               'place_holder': '',
-              'names': ['Matlab layout', 'Rstudio layout', 'Vertical split', 'Horizontal split'],
-              'order': ['Matlab layout', 'Rstudio layout', 'Vertical split', 'Horizontal split'],
-              'active': ['Matlab layout', 'Rstudio layout', 'Vertical split', 'Horizontal split'],
+              'names': [],
+              'order': [],
+              'active': [],
+              'ui_names': []
               }),
             ('internal_console',
              {
@@ -126,7 +134,6 @@ DEFAULTS = [
              {
               'show_banner': True,
               'completion_type': 0,
-              'use_pager': False,
               'show_calltips': True,
               'ask_before_closing': False,
               'show_reset_namespace_warning': True,
@@ -153,7 +160,12 @@ DEFAULTS = [
               # This is True because there are libraries like Pyomo
               # that generate a lot of Command Prompts while running,
               # and that's extremely annoying for Windows users.
-              'hide_cmd_windows': True
+              'hide_cmd_windows': True,
+              'pdb_prevent_closing': True,
+              'pdb_ignore_lib': False,
+              'pdb_execute_events': True,
+              'pdb_use_exclamation_mark': True,
+              'pdb_stop_first_line': True,
               }),
             ('variable_explorer',
              {
@@ -195,7 +207,7 @@ DEFAULTS = [
               'edge_line_columns': '79',
               'indent_guides': False,
               'code_folding': True,
-              'code_folding_warn': True,
+              'show_code_folding_warning': True,
               'scroll_past_end': False,
               'toolbox_panel': True,
               'close_parentheses': True,
@@ -212,7 +224,6 @@ DEFAULTS = [
               'automatic_completions': True,
               'automatic_completions_after_chars': 3,
               'automatic_completions_after_ms': 300,
-              'completions_wait_for_ms': 200,
               'completions_hint': True,
               'completions_hint_after_ms': 500,
               'underline_errors': False,
@@ -221,6 +232,8 @@ DEFAULTS = [
               'occurrence_highlighting': True,
               'occurrence_highlighting/timeout': 1500,
               'always_remove_trailing_spaces': False,
+              'add_newline': False,
+              'always_remove_trailing_newlines': False,
               'show_tab_bar': True,
               'show_class_func_dropdown': False,
               'max_recent_files': 20,
@@ -236,7 +249,6 @@ DEFAULTS = [
             ('historylog',
              {
               'enable': True,
-              'max_entries': 100,
               'wrap': True,
               'go_to_eof': True,
               'line_numbers': False,
@@ -250,11 +262,16 @@ DEFAULTS = [
               'connect/ipython_console': False,
               'math': True,
               'automatic_import': True,
+              'plain_mode': False,
+              'rich_mode': True,
+              'show_source': False,
+              'locked': False,
               }),
             ('onlinehelp',
              {
               'enable': True,
               'zoom_factor': .8,
+              'handle_links': False,
               'max_history_entries': 20,
               }),
             ('outline_explorer',
@@ -265,6 +282,8 @@ DEFAULTS = [
               'group_cells': True,
               'sort_files_alphabetically': False,
               'show_comments': True,
+              'follow_cursor': True,
+              'display_variables': False
               }),
             ('project_explorer',
              {
@@ -272,17 +291,16 @@ DEFAULTS = [
               'show_all': True,
               'show_hscrollbar': True,
               'max_recent_projects': 10,
-              'visible_if_project_open': True
+              'visible_if_project_open': True,
+              'date_column': False,
               }),
             ('explorer',
              {
               'enable': True,
-              'wrap': True,
               'name_filters': NAME_FILTERS,
-              'show_hidden': True,
-              'show_all': True,
-              'show_icontext': False,
+              'show_hidden': False,
               'single_click_to_open': False,
+              'file_associations': {},
               }),
             ('find_in_files',
              {
@@ -295,12 +313,23 @@ DEFAULTS = [
               'search_text_samples': [TASKS_PATTERN],
               'more_options': False,
               'case_sensitive': False,
+              'exclude_case_sensitive': False,
               'max_results': 1000,
               }),
             ('breakpoints',
              {
               'enable': True,
               }),
+            ('completions',
+             {
+               'enable': True,
+               'kite_call_to_action': True,
+               'enable_code_snippets': True,
+               'completions_wait_for_ms': 200,
+               'enabled_providers': {},
+               'provider_configuration': {},
+               'request_priorities': {}
+             }),
             ('profiler',
              {
               'enable': True,
@@ -308,6 +337,9 @@ DEFAULTS = [
             ('pylint',
              {
               'enable': True,
+              'history_filenames': [],
+              'max_entries': 30,
+              'project_dir': None,
               }),
             ('workingdir',
              {
@@ -326,12 +358,10 @@ DEFAULTS = [
               '_/lock unlock panes': "Shift+Ctrl+F5",
               '_/use next layout': "Shift+Alt+PgDown",
               '_/use previous layout': "Shift+Alt+PgUp",
-              '_/preferences': "Ctrl+Alt+Shift+P",
               '_/maximize pane': "Ctrl+Alt+Shift+M",
               '_/fullscreen mode': "F11",
               '_/save current layout': "Shift+Alt+S",
               '_/layout preferences': "Shift+Alt+P",
-              '_/show toolbars': "Alt+Shift+T",
               '_/spyder documentation': "F1",
               '_/restart': "Shift+Alt+R",
               '_/quit': "Ctrl+Q",
@@ -359,6 +389,8 @@ DEFAULTS = [
               '_/switch to find_in_files': "Ctrl+Shift+F",
               '_/switch to explorer': "Ctrl+Shift+X",
               '_/switch to plots': "Ctrl+Shift+G",
+              '_/switch to pylint': "Ctrl+Shift+C",
+              '_/switch to profiler': "Ctrl+Shift+R",
               # -- In widgets/findreplace.py
               'find_replace/find text': "Ctrl+F",
               'find_replace/find next': "F3",
@@ -425,8 +457,8 @@ DEFAULTS = [
               'editor/save as': 'Ctrl+Shift+S',
               'editor/close all': "Ctrl+Shift+W",
               'editor/last edit location': "Ctrl+Alt+Shift+Left",
-              'editor/previous cursor position': "Ctrl+Alt+Left",
-              'editor/next cursor position': "Ctrl+Alt+Right",
+              'editor/previous cursor position': "Alt+Left",
+              'editor/next cursor position': "Alt+Right",
               'editor/previous warning': "Ctrl+Alt+Shift+,",
               'editor/next warning': "Ctrl+Alt+Shift+.",
               'editor/zoom in 1': "Ctrl++",
@@ -445,6 +477,8 @@ DEFAULTS = [
               'editor/split horizontally': "Ctrl+_",
               'editor/close split panel': "Alt+Shift+W",
               'editor/docstring': "Ctrl+Alt+D",
+              'editor/autoformatting': "Ctrl+Alt+I",
+              'editor/show in external file explorer': '',
               # -- In Breakpoints
               '_/switch to breakpoints': "Ctrl+Shift+B",
               # ---- Consoles (in widgets/shell) ----
@@ -482,53 +516,10 @@ DEFAULTS = [
               'explorer/paste file': 'Ctrl+V',
               'explorer/copy absolute path': 'Ctrl+Alt+C',
               'explorer/copy relative path': 'Ctrl+Alt+Shift+C',
+              # ---- In plugins/findinfiles/plugin ----
+              'find_in_files/find in files': 'Ctrl+Alt+F',
               }),
             ('appearance', APPEARANCE),
-            ('lsp-server',
-             {
-              # This option is not used with the LSP server config
-              # It is used to disable hover hints in the editor
-              'enable_hover_hints': True,
-              'code_completion': True,
-              'code_snippets': True,
-              'jedi_definition': True,
-              'jedi_definition/follow_imports': True,
-              'jedi_signature_help': True,
-              'preload_modules': PRELOAD_MDOULES,
-              'pyflakes': True,
-              'mccabe': False,
-              'pycodestyle': False,
-              'pycodestyle/filename': '',
-              'pycodestyle/exclude': '',
-              'pycodestyle/select': '',
-              'pycodestyle/ignore': '',
-              'pycodestyle/max_line_length': 79,
-              'pydocstyle': False,
-              'pydocstyle/convention': 'numpy',
-              'pydocstyle/select': '',
-              'pydocstyle/ignore': '',
-              'pydocstyle/match': '(?!test_).*\\.py',
-              'pydocstyle/match_dir': '[^\\.].*',
-              'advanced/enabled': False,
-              'advanced/module': 'pyls',
-              'advanced/host': '127.0.0.1',
-              'advanced/port': 2087,
-              'advanced/external': False,
-              'advanced/stdio': False
-             }),
-            ('fallback-completions',
-             {
-              'enable': True,
-             }),
-            ('kite',
-             {
-              'enable': True,
-              'call_to_action': True,
-              # Enable the installation dialog
-              'show_installation_dialog': True,
-              'show_onboarding': True,
-              'show_installation_error_message': True,
-             }),
             ]
 
 
@@ -545,7 +536,6 @@ NAME_MAP = {
             'crash',
             'current_version',
             'historylog_filename',
-            'last_visible_toolbars',
             'spyder_pythonpath',
             'window/position',
             'window/prefs_dialog_size',
@@ -553,8 +543,8 @@ NAME_MAP = {
             'window/state',
             ]
          ),
-        ('appearance', [
-            'windows_style',
+        ('toolbar', [
+            'last_visible_toolbars',
             ]
          ),
         ('editor', [
@@ -572,6 +562,8 @@ NAME_MAP = {
         ('find_in_files', [
             'path_history'
             'search_text',
+            'exclude_index',
+            'search_in_index',
             ]
          ),
         ('main_interpreter', [
@@ -610,6 +602,10 @@ NAME_MAP = {
             'startup/fixed_directory',
           ]
          ),
+        ('pylint', [
+          'history_filenames',
+          ]
+         ),
     ]
 }
 
@@ -624,4 +620,4 @@ NAME_MAP = {
 #    or if you want to *rename* options, then you need to do a MAJOR update in
 #    version, e.g. from 3.0.0 to 4.0.0
 # 3. You don't need to touch this value if you're just adding a new option
-CONF_VERSION = '56.0.0'
+CONF_VERSION = '69.1.0'
