@@ -31,22 +31,24 @@ from qtpy.QtWidgets import (QHBoxLayout, QLabel, QMenu, QMessageBox,
                             QToolButton, QVBoxLayout, QWidget)
 
 # Local imports
-from spyder.config.base import (_, get_image_path, get_module_source_path,
+from spyder.config.base import (_, get_module_source_path,
                                 running_under_pytest)
 from spyder.config.manager import CONF
-from spyder.utils import icon_manager as ima
+from spyder.utils.icon_manager import ima
 from spyder.utils import sourcecode
+from spyder.utils.image_path_manager import get_image_path
 from spyder.utils.encoding import get_coding
 from spyder.utils.environ import RemoteEnvDialog
+from spyder.utils.palette import QStylePalette
 from spyder.utils.programs import get_temp_dir
 from spyder.utils.qthelpers import (add_actions, create_action,
                                     create_toolbutton, DialogManager,
                                     MENU_SEPARATOR)
 from spyder.py3compat import to_text_string
 from spyder.plugins.ipythonconsole.widgets import ShellWidget
+from spyder.utils.stylesheet import PANES_TABBAR_STYLESHEET
+from spyder.widgets.collectionseditor import CollectionsEditor
 from spyder.widgets.mixins import SaveHistoryMixin
-from spyder.plugins.variableexplorer.widgets.collectionseditor import (
-        CollectionsEditor)
 
 
 #-----------------------------------------------------------------------------
@@ -482,6 +484,7 @@ class ClientWidget(QWidget, SaveHistoryMixin):
             self.stop_button.clicked.connect(self.stop_button_click_handler)
         if self.stop_button is not None:
             buttons.append(self.stop_button)
+        self.stop_button.setStyleSheet(str(PANES_TABBAR_STYLESHEET))
 
         # Reset namespace button
         if self.reset_button is None:
@@ -493,7 +496,7 @@ class ClientWidget(QWidget, SaveHistoryMixin):
                                     triggered=self.reset_namespace)
         if self.reset_button is not None:
             buttons.append(self.reset_button)
-
+        self.reset_button.setStyleSheet(str(PANES_TABBAR_STYLESHEET))
         if self.options_button is None:
             options = self.get_options_menu()
             if options:
@@ -622,6 +625,11 @@ class ClientWidget(QWidget, SaveHistoryMixin):
                 sw.kernel_manager.autorestart = False
 
                 # Create and run restarting thread
+                if (self.restart_thread is not None
+                        and self.restart_thread.isRunning()):
+                    self.restart_thread.finished.disconnect()
+                    self.restart_thread.terminate()
+                    self.restart_thread.wait()
                 self.restart_thread = QThread()
                 self.restart_thread.run = self._restart_thread_main
                 self.restart_thread.error = None
@@ -671,8 +679,9 @@ class ClientWidget(QWidget, SaveHistoryMixin):
             # setting of %colors on windows by assuming it was using a
             # dark background. This corrects it based on the scheme.
             self.set_color_scheme(sw.syntax_style, reset=reset)
-            sw._append_html(_("<br>Restarting kernel...\n<hr><br>"),
+            sw._append_html(_("<br>Restarting kernel...<br>"),
                             before_prompt=True)
+            sw.insert_horizontal_ruler()
 
         self._hide_loading_page()
         self.stop_button.setDisabled(True)
@@ -756,9 +765,9 @@ class ClientWidget(QWidget, SaveHistoryMixin):
         else:
             fmt = "%H:%M:%S"
         if end:
-            color = "#AAAAAA"
+            color = QStylePalette.COLOR_TEXT_3
         else:
-            color = "#AA6655"
+            color = QStylePalette.COLOR_ACCENT_4
         text = "<span style=\'color: %s\'><b>%s" \
                "</b></span>" % (color,
                                 time.strftime(fmt, time.gmtime(elapsed_time)))
@@ -787,7 +796,7 @@ class ClientWidget(QWidget, SaveHistoryMixin):
     def _create_loading_page(self):
         """Create html page to show while the kernel is starting"""
         loading_template = Template(LOADING)
-        loading_img = get_image_path('loading_sprites.png')
+        loading_img = get_image_path('loading_sprites')
         if os.name == 'nt':
             loading_img = loading_img.replace('\\', '/')
         message = _("Connecting to kernel...")
